Pytilities is a python3 utility library.

Links
=====

- `Pytilities homepage`_
- `Documentation`_


Features
========

- Aspect oriented programming: 

  - Create Aspects to bundle advice
  - Apply advice to any attribute of an instance or all instances of a class.
    Can even be applied to attributes that don't exist on the instance (i.e.
    create it). Can also be applied to any attribute of an object.

- Event dispatching: Observer/Subject like event dispatching with wrappers
  for hiding events on dispatchers and combining dispatchers
- Function overloading
- Basic geometry: Vector, Rectangle classes
- Various: cross platform infinity number, ...


.. _Pytilities homepage: http://pytilities.sourceforge.net/
.. _Documentation: http://pytilities.sourceforge.net/doc/1.2.0/
